==> loadmychunks-1.2.0%2B1.16.5%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/debug/LoadMyChunksDebug.java <==
package com.drathonix.loadmychunks.common.debug;

//? if <1.16.6 {
import me.shedaniel.architectury.event.events.CommandRegistrationEvent;
import me.shedaniel.architectury.registry.RegistrySupplier;
import net.minecraft.class_2168;
import net.minecraft.class_2170;
import net.minecraft.class_2248;
import net.minecraft.class_2585;
import net.minecraft.class_2591;
import net.minecraft.class_3614;
import net.minecraft.class_4970;
//?}
import com.drathonix.loadmychunks.common.util.MultiversioningHelper;
import com.drathonix.loadmychunks.unified.BlockEntityTypeBuilder;

import com.mojang.brigadier.CommandDispatcher;
import com.mojang.brigadier.arguments.IntegerArgumentType;
import com.drathonix.loadmychunks.common.registry.LMCContent;
import com.drathonix.loadmychunks.common.registry.LMCRegistrar;
import com.drathonix.loadmychunks.common.util.ModResource;
import java.util.*;
import java.util.function.Supplier;


public class LoadMyChunksDebug {
    static int laggerMsSleep = 1;

    static RegistrySupplier<class_2591<DebugBlockEntityLagger>> laggerBlockEntity;

    //? if >1.19.4 {
    /*public static void init(){
        LMCRegistrar.BLOCK.queue(reg->{
            RegistrySupplier<DebugBlockLagger> laggerBlock = LMCContent.registerBlockWithItem(reg,"lagger",()->new DebugBlockLagger(MultiversioningHelper.properties("lagger")));
            LMCRegistrar.BLOCK_ENTITY_TYPE.queue(breg->{
                LoadMyChunksDebug.laggerBlockEntity = breg.register(ModResource.of("lagger"), () -> BlockEntityTypeBuilder.build(DebugBlockEntityLagger::new,List.of(laggerBlock.get())));
            });
        });
        CommandRegistrationEvent.EVENT.register(LoadMyChunksDebug::registerCommands);
    }
    *///?}

    //? if >1.18.2 {
    /*static void registerCommands(CommandDispatcher<CommandSourceStack> dispatcher, CommandBuildContext registry, Commands.CommandSelection selection) {
        dispatcher.register(Commands.literal("lmcdebug").then(Commands.literal("lagger").then(Commands.literal("sleep").executes(ctx->{
            ctx.getSource().sendSystemMessage(Component.literal("Sleep time is " + laggerMsSleep));
            return 0;
        }).then(Commands.argument("delay",IntegerArgumentType.integer()).executes(ctx->{
            laggerMsSleep = IntegerArgumentType.getInteger(ctx,"delay");
            ctx.getSource().sendSystemMessage(Component.literal("Sleep time set to " + laggerMsSleep));
            return 0;
        })))));
    }
    *///?}

    //? if <1.19.5 {
    public static void init(){
        LMCRegistrar.BLOCK.queue(reg->{
            Supplier<DebugBlockLagger> laggerBlock = LMCContent.registerBlockWithItem(reg,"lagger",()->new DebugBlockLagger(class_4970.class_2251.method_9637(class_3614.field_15914)));
            LMCRegistrar.BLOCK_ENTITY_TYPE.queue(breg->{
                LoadMyChunksDebug.laggerBlockEntity = breg.register(ModResource.of("lagger"), () -> {
                    Set<class_2248> blocks = new HashSet<>();
                    blocks.add(laggerBlock.get());
                    return BlockEntityTypeBuilder.build(DebugBlockEntityLagger::new, blocks);
                });
            });
        });
        CommandRegistrationEvent.EVENT.register(LoadMyChunksDebug::registerCommands);
    }
    //?}
    //? if <1.18.3 {
    static void registerCommands(CommandDispatcher<class_2168> dispatcher, class_2170.class_5364 selection) {
        dispatcher.register(class_2170.method_9247("lmcdebug").then(class_2170.method_9247("lagger").then(class_2170.method_9247("sleep").executes(ctx->{
            ctx.getSource().method_9226(new class_2585("Sleep time is " + laggerMsSleep),false);
            return 0;
        }).then(class_2170.method_9244("delay",IntegerArgumentType.integer()).executes(ctx->{
            laggerMsSleep = IntegerArgumentType.getInteger(ctx,"delay");
            ctx.getSource().method_9226(new class_2585("Sleep time set to " + laggerMsSleep),false);
            return 0;
        })))));
    }
    //?}
}

==> loadmychunks-1.2.1%2B1.18.2%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/debug/LoadMyChunksDebug.java <==
package com.drathonix.loadmychunks.common.debug;

//? if <1.16.6 {
/*import me.shedaniel.architectury.event.events.CommandRegistrationEvent;
import me.shedaniel.architectury.registry.RegistrySupplier;

*///?}
import com.drathonix.loadmychunks.common.util.MultiversioningHelper;
import com.drathonix.loadmychunks.unified.BlockEntityTypeBuilder;

import com.mojang.brigadier.CommandDispatcher;
import com.mojang.brigadier.arguments.IntegerArgumentType;
import com.drathonix.loadmychunks.common.registry.LMCContent;
import com.drathonix.loadmychunks.common.registry.LMCRegistrar;
import com.drathonix.loadmychunks.common.util.ModResource;
//? if >1.16.5 {
import dev.architectury.event.events.common.CommandRegistrationEvent;
import dev.architectury.registry.registries.RegistrySupplier;
import java.util.*;
import java.util.function.Supplier;
import net.minecraft.class_2168;
import net.minecraft.class_2170;
import net.minecraft.class_2248;
import net.minecraft.class_2585;
import net.minecraft.class_2591;
import net.minecraft.class_3614;
import net.minecraft.class_4970;


public class LoadMyChunksDebug {
    static int laggerMsSleep = 1;

    static RegistrySupplier<class_2591<DebugBlockEntityLagger>> laggerBlockEntity;

    //? if >1.19.4 {
    /*public static void init(){
        LMCRegistrar.BLOCK.queue(reg->{
            RegistrySupplier<DebugBlockLagger> laggerBlock = LMCContent.registerBlockWithItem(reg,"lagger",()->new DebugBlockLagger(MultiversioningHelper.properties("lagger")));
            LMCRegistrar.BLOCK_ENTITY_TYPE.queue(breg->{
                LoadMyChunksDebug.laggerBlockEntity = breg.register(ModResource.of("lagger"), () -> BlockEntityTypeBuilder.build(DebugBlockEntityLagger::new,List.of(laggerBlock.get())));
            });
        });
        CommandRegistrationEvent.EVENT.register(LoadMyChunksDebug::registerCommands);
    }
    *///?}

    //? if >1.18.2 {
    /*static void registerCommands(CommandDispatcher<CommandSourceStack> dispatcher, CommandBuildContext registry, Commands.CommandSelection selection) {
        dispatcher.register(Commands.literal("lmcdebug").then(Commands.literal("lagger").then(Commands.literal("sleep").executes(ctx->{
            ctx.getSource().sendSystemMessage(Component.literal("Sleep time is " + laggerMsSleep));
            return 0;
        }).then(Commands.argument("delay",IntegerArgumentType.integer()).executes(ctx->{
            laggerMsSleep = IntegerArgumentType.getInteger(ctx,"delay");
            ctx.getSource().sendSystemMessage(Component.literal("Sleep time set to " + laggerMsSleep));
            return 0;
        })))));
    }
    *///?}

    //? if <1.19.5 {
    public static void init(){
        LMCRegistrar.BLOCK.queue(reg->{
            Supplier<DebugBlockLagger> laggerBlock = LMCContent.registerBlockWithItem(reg,"lagger",()->new DebugBlockLagger(class_4970.class_2251.method_9637(class_3614.field_15914)));
            LMCRegistrar.BLOCK_ENTITY_TYPE.queue(breg->{
                LoadMyChunksDebug.laggerBlockEntity = breg.register(ModResource.of("lagger"), () -> {
                    Set<class_2248> blocks = new HashSet<>();
                    blocks.add(laggerBlock.get());
                    return BlockEntityTypeBuilder.build(DebugBlockEntityLagger::new, blocks);
                });
            });
        });
        CommandRegistrationEvent.EVENT.register(LoadMyChunksDebug::registerCommands);
    }
    //?}
    //? if <1.18.3 {
    static void registerCommands(CommandDispatcher<class_2168> dispatcher, class_2170.class_5364 selection) {
        dispatcher.register(class_2170.method_9247("lmcdebug").then(class_2170.method_9247("lagger").then(class_2170.method_9247("sleep").executes(ctx->{
            ctx.getSource().method_9226(new class_2585("Sleep time is " + laggerMsSleep),false);
            return 0;
        }).then(class_2170.method_9244("delay",IntegerArgumentType.integer()).executes(ctx->{
            laggerMsSleep = IntegerArgumentType.getInteger(ctx,"delay");
            ctx.getSource().method_9226(new class_2585("Sleep time set to " + laggerMsSleep),false);
            return 0;
        })))));
    }
    //?}
}
